==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/catnip/gui/render/GradientRectRenderState.java <==
package com.zurrtum.create.client.catnip.gui.render;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import com.zurrtum.create.catnip.theme.Color;
import net.minecraft.class_10799;
import net.minecraft.class_11231;
import net.minecraft.class_11244;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix3x2f;

public record GradientRectRenderState(
    Matrix3x2f pose, float left, float top, float right, float bottom, int startRed, int startGreen, int startBlue, int startAlpha, int endRed,
    int endGreen, int endBlue, int endAlpha, class_8030 bounds
) implements class_11244 {
    public GradientRectRenderState(Matrix3x2f pose, float left, float top, float right, float bottom, Color startColor, Color endColor) {
        this(
            pose,
            left,
            top,
            right,
            bottom,
            startColor.getRed(),
            startColor.getGreen(),
            startColor.getBlue(),
            startColor.getAlpha(),
            endColor.getRed(),
            endColor.getGreen(),
            endColor.getBlue(),
            endColor.getAlpha(),
            new class_8030((int) left, (int) top, (int) (right - left), (int) (bottom - top)).method_71523(pose)
        );
    }

    @Override
    public RenderPipeline comp_4055() {
        return class_10799.field_56865;
    }

    @Override
    public void method_70917(class_4588 vertexConsumer, float depth) {
        vertexConsumer.method_70815(pose, right, top, depth).method_1336(startRed, startGreen, startBlue, startAlpha);
        vertexConsumer.method_70815(pose, left, top, depth).method_1336(startRed, startGreen, startBlue, startAlpha);
        vertexConsumer.method_70815(pose, left, bottom, depth).method_1336(endRed, endGreen, endBlue, endAlpha);
        vertexConsumer.method_70815(pose, right, bottom, depth).method_1336(endRed, endGreen, endBlue, endAlpha);
    }

    @Override
    public class_11231 comp_4056() {
        return class_11231.method_70899();
    }

    @Override
    public @Nullable class_8030 comp_4069() {
        return null;
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/catnip/gui/render/GradientRectRenderState.java <==
package com.zurrtum.create.client.catnip.gui.render;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import com.zurrtum.create.catnip.theme.Color;
import net.minecraft.class_10799;
import net.minecraft.class_11231;
import net.minecraft.class_11244;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix3x2f;

public record GradientRectRenderState(
    Matrix3x2f pose, float left, float top, float right, float bottom, int startRed, int startGreen, int startBlue, int startAlpha, int endRed,
    int endGreen, int endBlue, int endAlpha, class_8030 bounds
) implements class_11244 {
    public GradientRectRenderState(Matrix3x2f pose, float left, float top, float right, float bottom, Color startColor, Color endColor) {
        this(
            pose,
            left,
            top,
            right,
            bottom,
            startColor.getRed(),
            startColor.getGreen(),
            startColor.getBlue(),
            startColor.getAlpha(),
            endColor.getRed(),
            endColor.getGreen(),
            endColor.getBlue(),
            endColor.getAlpha(),
            new class_8030((int) left, (int) top, (int) (right - left), (int) (bottom - top)).method_71523(pose)
        );
    }

    @Override
    public RenderPipeline comp_4055() {
        return class_10799.field_56865;
    }

    @Override
    public void method_70917(class_4588 vertexConsumer) {
        vertexConsumer.method_70815(pose, right, top).method_1336(startRed, startGreen, startBlue, startAlpha);
        vertexConsumer.method_70815(pose, left, top).method_1336(startRed, startGreen, startBlue, startAlpha);
        vertexConsumer.method_70815(pose, left, bottom).method_1336(endRed, endGreen, endBlue, endAlpha);
        vertexConsumer.method_70815(pose, right, bottom).method_1336(endRed, endGreen, endBlue, endAlpha);
    }

    @Override
    public class_11231 comp_4056() {
        return class_11231.method_70899();
    }

    @Override
    public @Nullable class_8030 comp_4069() {
        return null;
    }
}
